FormattedHelloWorld

Struct FormattedHelloWorld 

pub struct FormattedHelloWorld<'l> {
    data: &'l HelloWorld<'l>,
}
A formatted hello world message. Implements Writeable.

For an example, see HelloWorldFormatter.

Fields

data: &'l HelloWorld<'l>

Implementations

Source

impl FormattedHelloWorld<'_>

pub fn to_string(&self) -> String

Converts the given value to a String.

Under the hood, this uses an efficient Writeable implementation.

If you don’t need an allocated String, but e.g. need to write this to some sink, it is more efficient to use Writeable directly.